#!/bin/bash

# 检查Homebrew是否安装
if ! command -v brew &>/dev/null; then
    echo "Homebrew 未安装。安装 Homebrew..."
    /bin/bash -c "$(curl -fsSL https://raw.githubusercontent.com/Homebrew/install/HEAD/install.sh)" || {
        echo "Homebrew 安装失败，请手动安装 Homebrew 后重试。"
        exit 1
    }
else
    echo "Homebrew 已安装。"
fi

# 安装 Python 3 和 pip
echo "安装 Python 3 和 pip..."
brew install python || {
    echo "Python 3 安装失败，请检查 Homebrew 是否正常工作。"
    exit 1
}

# 验证 Python 3 和 pip 安装
echo "验证 Python 3 和 pip 安装..."
if ! python3 --version &>/dev/null; then
    echo "Python 3 未成功安装。"
    exit 1
else
    python3 --version
fi

if ! pip3 --version &>/dev/null; then
    echo "pip 未成功安装。"
    exit 1
else
    pip3 --version
fi

# 创建虚拟环境
echo "创建虚拟环境..."
python3 -m venv venv || {
    echo "虚拟环境创建失败。"
    exit 1
}

# 激活虚拟环境
echo "激活虚拟环境..."
source ./venv/bin/activate || {
    echo "虚拟环境激活失败。"
    exit 1
}

# 安装 chattts-fork 库
echo "安装 chattts-fork 库..."
pip install chattts-fork || {
    echo "chattts-fork 安装失败。"
    deactivate
    exit 1
}

# 使用 chattts-fork 进行文本转语音
echo "测试 chattts-fork 进行文本转语音..."
chattts '你好你好' || {
    echo "文本转语音失败，请检查 chattts-fork 是否正常工作。"
    deactivate
    exit 1
}

# 测试带种子的文本转语音
echo "测试带种子的文本转语音..."
chattts '我笑他人看不穿' --seed 2222 || {
    echo "带种子的文本转语音失败，请检查 chattts-fork 是否正常工作。"
    deactivate
    exit 1
}

echo "教程执行完毕。所有步骤成功完成！"

# 关闭虚拟环境
deactivate
